#
# spec file for package python-rpcq
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-rpcq
Version:        3.10.0
Release:        1.20
Summary:        The RPC framework and message specification for Rigetti QCS
License:        Apache-2.0
URL:            https://github.com/rigetti/rpcq
Source:         https://github.com/rigetti/rpcq/archive/v%{version}.tar.gz#/rpcq-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module msgpack >= 0.6}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module python-rapidjson}
BuildRequires:  %{python_module pyzmq >= 17}
BuildRequires:  %{python_module ruamel.yaml}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-msgpack >= 0.6
Requires:       python-python-rapidjson
Requires:       python-pyzmq >= 17
Requires:       python-ruamel.yaml
# SECTION test
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}

# /SECTION
BuildArch:      noarch
%python_subpackages

%description
The RPC framework and message specification for Rigetti QCS.

%prep
%setup -q -n rpcq-%{version}
# Fix non-executable-script
sed -i '/^#!/d' rpcq/core_messages.py
sed -i '/^#!/d' rpcq/messages.py
# unpin msgpack and ignore gh#rigetti/pyqui#1178
sed -i '/msgpack/ s/,<1.0//' setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_client_warning stall for unknown reason.
%pytest -k "not (test_client_warning)"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/rpcq-%{version}.dist-info
%{python_sitelib}/rpcq

%changelog
* Sat Jan 28 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.10.0
  * Update: Add new execution results message
- Version 3.9.2
  * Rework types calculation with locks
- Fix requirements, unpin msgpack
* Tue Apr 20 2021 andy great <andythe_great@pm.me>
- Update to 3.9.1.
  * No changelog given.
* Thu Apr 15 2021 andy great <andythe_great@pm.me>
- Update to version 3.9.0.
  * No changelog given.
* Sat Jan 30 2021 andy great <andythe_great@pm.me>
- Fix RPMLINT warning non-executable-script.
- Zero length rpcq/py.typed must be kept for PEP 561 compliance.
- Disable build for python 3.6 because numpy will not support it.
* Fri Jan 29 2021 andy great <andythe_great@pm.me>
- Update to version 3.8.0.
  * No changelog given.
* Sat Jan 16 2021 andy great <andythe_great@pm.me>
- Update to version 3.7.0.
  * Add mnio_connections section
  * Import messages and core_messages in rpcq module init
  * Allow None for optional bools
  * Correctly report timeout in timeout error messages
    Fix for breaking change in upstream cl-messagepack
* Thu Nov 26 2020 andy great <andythe_great@pm.me>
- Update to version 3.6.0.
  * Add YokogawaGS200Channel message
- Updates since 3.4.0.
  * Add QDOSequencer, QDOSlowFluxChannel, and QDOFastFluxChannel.
* Tue Aug 18 2020 andy great <andythe_great@pm.me>
- Initial package release.
